@@ -3,8 +3,7 @@ package Eixo::Docker::ImageResume;
 use strict;
 use warnings;
 
-use Eixo::Rest::Product;
-use parent qw(Eixo::Rest::Product);
+use Eixo::Base::Clase qw(Eixo::Rest::Product);
 
 has(
 
@@ -17,3 +16,5 @@ has(
     ParentId=>undef,
 
 );
+
+1;
